Create a plot of posterior means and credible intervals.
Arguments
- results
List from
consolidate_results().- H
Integer. Which H value to plot.
- data
Optional. Observations to overlay (default NULL).
- title
Optional plot title (default NULL).
Create a plot of posterior means and credible intervals.
List from consolidate_results().
Integer. Which H value to plot.
Optional. Observations to overlay (default NULL).
Optional plot title (default NULL).