Plot posterior predictions with observed data overlaid.
Arguments
- results
List from
consolidate_results().- sim
Simulation or data list with years and z (observations).
- title
Optional plot title (default NULL).
Plot posterior predictions with observed data overlaid.
List from consolidate_results().
Simulation or data list with years and z (observations).
Optional plot title (default NULL).